package com.pcag.java.oea.plugins.demoexchange2008.preferences;

import org.eclipse.jface.preference.DirectoryFieldEditor;
import org.eclipse.jface.preference.FieldEditorPreferencePage;
import org.eclipse.jface.preference.IntegerFieldEditor;
import org.eclipse.jface.preference.StringFieldEditor;
import org.eclipse.ui.IWorkbench;
import org.eclipse.ui.IWorkbenchPreferencePage;

import com.pcag.java.oea.plugins.demoexchange2008.Activator;

/**
 * This class represents a preference page that is contributed to the
 * Preferences dialog. By subclassing <samp>FieldEditorPreferencePage</samp>,
 * we can use the field support built into JFace that allows us to create a page
 * that is small and knows how to save, restore and apply itself.
 * <p>
 * This page is used to modify preferences only. They are stored in the
 * preference store that belongs to the main plug-in class. That way,
 * preferences can be accessed directly via the preference store.
 */

public class DemoexchangePreferencePage extends FieldEditorPreferencePage
		implements IWorkbenchPreferencePage {

	public DemoexchangePreferencePage() {
		super(GRID);
		setPreferenceStore(Activator.getDefault().getPreferenceStore());
		setDescription("Select defaults for generated database connections");
	}

	/**
	 * Creates the field editors. Field editors are abstractions of the common GUI
	 * blocks needed to manipulate various types of preferences. Each field editor
	 * knows how to save and restore itself.
	 */
	public void createFieldEditors() {
		addField(new DirectoryFieldEditor(PreferenceConstants.P_DBSCRIPTDIRPATH,
				"DBS&cript directory:", getFieldEditorParent()));
		addField(new IntegerFieldEditor(PreferenceConstants.P_DBPORTOFFSET,
				"DB &port next value:", getFieldEditorParent()));
		addField(new StringFieldEditor(PreferenceConstants.P_DBUSERNAME,
				"DB &username (default):", getFieldEditorParent()));
		addField(new StringFieldEditor(PreferenceConstants.P_DBPASSWORD,
				"DB &password (default):", getFieldEditorParent()));
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.ui.IWorkbenchPreferencePage#init(org.eclipse.ui.IWorkbench)
	 */
	public void init(IWorkbench workbench) {
	}

}