package com.pcag.java.oea.plugins.demoexchange2008.wizard;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.Preferences;

import com.openedge.pdt.core.util.CorePdtUtil;
import com.openedge.pdt.text.OEPlugin;
import com.openedge.pdt.text.connection.DatabaseConnectionManager;
import com.openedge.pdt.text.connection.DatabaseConnectionProfile;
import com.pcag.java.oea.plugins.demoexchange2008.Activator;
import com.pcag.java.oea.plugins.demoexchange2008.model.api.IDBType;
import com.pcag.java.oea.plugins.demoexchange2008.preferences.PreferenceConstants;

public class ConnectionFactory {

	public static DatabaseConnectionProfile createDatabaseConfiguration(
			IProject project2, String namePrefix, IDBType dbtype, String username,
			String password) throws CoreException {

		String basePath = "";
		DatabaseConnectionProfile conn;
		String dbname = getDbConnectionName(namePrefix, dbtype);

		/* Calculate db's base path if project is given */
		if (project2 != null)
			basePath = getBase(project2);

		/* Check if Databaseconnection is already known. In that case do nothing */
		conn = searchDbConnection(dbname);
		if (conn != null)
			return conn;

		/* Calculate next free port number. */
		int offset = calcFreePort(dbtype);

		/* Create database */
		conn = new DatabaseConnectionProfile(dbname);
		conn.setAutoStartServer(true);
		conn.setAutoShutdownServer(true);
		conn.setServerParameters("-db " + basePath + "/" + namePrefix + "/db/"
				+ dbtype.getPhysicalName() + ".db -H localhost -S "
				+ Integer.toString(offset) + " -B 2000");
		conn.setLogicalName(dbtype.getLogicalName());
		conn.setHost("localhost");
		conn.setService(Integer.toString(offset));
		conn.setPhysicalName(dbtype.getPhysicalName() + ".db");
		conn.setChecked(true);
		conn.setConnected(true);
		conn.setUser(username);
		conn.setPassword(password);
		conn.setProVersion(CorePdtUtil.getDefaultProgressVersion());

		return conn;
	} // createDatabaseConfiguration

	public static String getDbConnectionName(String namePrefix, IDBType dbtype) {
		String dbname = namePrefix.toLowerCase() + "_" + dbtype.getPhysicalName();
		return dbname;
	}

	/**
	 * Search for DatabaseConnectionProfile identified by name <code>dbname</code>
	 * 
	 * @param dbname
	 *          name of connection
	 * @return connection or null, if not found.
	 */
	public static DatabaseConnectionProfile searchDbConnection(String dbname) {

		OEPlugin oeplugin = OEPlugin.getDefault();
		DatabaseConnectionManager dbmanager = oeplugin
				.getDatabaseConnectionManager();
		DatabaseConnectionProfile[] knownConnections = dbmanager
				.getDatabaseConnectionProfiles();

		for (DatabaseConnectionProfile profile : knownConnections) {
			if (profile.getName().equals(dbname)) {
				return profile;
			}
		}

		return null;
	}

	private static String getBase(IProject project) {
		String result;

		result = project.getWorkspace().getRoot().getLocation().toString();

		return result;

	} // getBase

	/**
	 * @param dbtype
	 *          type of database the portnumber is needed for
	 * @return generated port number
	 */
	private static int calcFreePort(IDBType dbtype) {
		Preferences prefs = Activator.getDefault().getPluginPreferences();
		int baseoffset = prefs.getInt(PreferenceConstants.P_DBPORTOFFSET);
		int offset = baseoffset + dbtype.getPortOffset();
		return offset;
	}

	/**
	 * Increment internal port offset by 20
	 */
	public static void updateFreePortOffset() {
		Preferences prefs = Activator.getDefault().getPluginPreferences();
		int baseoffset = prefs.getInt(PreferenceConstants.P_DBPORTOFFSET);
		prefs.setValue(PreferenceConstants.P_DBPORTOFFSET, baseoffset + 20);
	}

}
