package com.pcag.java.oea.plugins.demoexchange2008.wizard;

import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.ui.IWorkbench;
import org.eclipse.ui.wizards.newresource.BasicNewResourceWizard;

import com.openedge.pdt.text.OEPlugin;
import com.openedge.pdt.text.connection.DatabaseConnectionManager;
import com.openedge.pdt.text.connection.DatabaseConnectionProfile;
import com.pcag.java.oea.plugins.demoexchange2008.Activator;
import com.pcag.java.oea.plugins.demoexchange2008.model.DBType;
import com.pcag.java.oea.plugins.demoexchange2008.model.DefaultDBTypes;
import com.pcag.java.oea.plugins.demoexchange2008.model.api.IDBType;

public class NewDatabaseconnectionWizard extends BasicNewResourceWizard {

	public NewDatabaseconnectionWizard() {
		super();
		setNeedsProgressMonitor(true);
		setWindowTitle("Create new database connections");
	}

	private NewDatabaseconnectionWizardPage page1;

	public void init(IWorkbench workbench, IStructuredSelection selection) {
		super.init(workbench, selection);
	}

	@Override
	public boolean performFinish() {
		boolean result = true;

		/* get plugin base information and get database manager */
		OEPlugin oeplugin = OEPlugin.getDefault();
		DatabaseConnectionManager dbmanager = oeplugin
				.getDatabaseConnectionManager();

		/*
		 * Create an array of our 3 standard databases we like to create connection
		 * information for
		 */
		IDBType[] dblist = new IDBType[3];

		dblist[0] = new DBType(DefaultDBTypes.FIX);
		dblist[1] = new DBType(DefaultDBTypes.VAR);
		dblist[2] = new DBType(DefaultDBTypes.TMP);

		/*
		 * Iterator and create connection informations and add them to the
		 * connection manager
		 */
		try {
			for (IDBType dbtype : dblist) {
				DatabaseConnectionProfile[] connections = new DatabaseConnectionProfile[1];
				connections[0] = ConnectionFactory.createDatabaseConfiguration(null,
						page1.getNamePrefix(), dbtype, page1.getUsername(), page1
								.getPassword());

				dbmanager.addDatabaseConnectionProfile(connections);
			}
		} catch (Exception e) {
			MessageDialog.openError(null, "Error while creating database connection",
					e.getLocalizedMessage());
			result = false;
		}

		/* Update the port offset for next creation */
		ConnectionFactory.updateFreePortOffset();

		return result;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.jface.wizard.Wizard#addPages()
	 */

	@Override
	public void addPages() {
		super.addPages();

		page1 = new NewDatabaseconnectionWizardPage("Init connections");
		this.addPage(page1);

	}

	/*
	 * (non-Javadoc) Method declared on BasicNewResourceWizard.
	 */
	protected void initializeDefaultPageImageDescriptor() {
		ImageDescriptor desc = Activator.getImageDescriptor("icons/proalpha.png"); 
			
		setDefaultPageImageDescriptor(desc);
	}

}
